fn parse_hardfork(
hf: &str,
networks: &NetworkConfigs,
) -> Result<FoundryHardfork>Available on crate feature
cmd only.Expand description
Parses a hardfork string against the active network configuration.
fn parse_hardfork(
hf: &str,
networks: &NetworkConfigs,
) -> Result<FoundryHardfork>cmd only.Parses a hardfork string against the active network configuration.